# UniBert  

Implementation of bert generation & multi-class classification for PyTorch. 

## Installation

### From Source
Git clone this project and install requirement  
```
pip install -r requirements.txt
```